@@ -10,6 +10,7 @@ from pydantic_core import PydanticUndefined
 from speedict import Rdict
 
 import fastworkflow
+from fastworkflow.utils.logging import logger
 from fastworkflow import Action, CommandOutput, CommandResponse, ModuleType, NLUPipelineStage
 from fastworkflow.cache_matching import cache_match, store_utterance_cache
 from fastworkflow.command_executor import CommandExecutor
@@ -34,6 +35,7 @@ INVALID_INFORMATION_ERRMSG = fastworkflow.get_env_var("INVALID_INFORMATION_ERRMS
 
 NOT_FOUND = fastworkflow.get_env_var("NOT_FOUND")
 INVALID = fastworkflow.get_env_var("INVALID")
+PARAMETER_EXTRACTION_ERROR_MSG = None
 
 
 class CommandNamePrediction:
@@ -78,7 +80,7 @@ class CommandNamePrediction:
             valid_command_names = (
                 set(cme_command_names) | 
                 set(app_crd.get_command_names(command_context_name))
-            ) - {'wildcard'}
+            )
 
         command_name_dict = {
             fully_qualified_command_name.split('/')[-1]: fully_qualified_command_name 
@@ -336,17 +338,28 @@ class ParameterExtraction:
 
         stored_params = self._get_stored_parameters(self.cme_workflow)
 
-        input_for_param_extraction = InputForParamExtraction.create(self.app_workflow, self.command_name, self.command)
+        self.command = self.command.replace(self.command_name, "").strip()
+
+        input_for_param_extraction = InputForParamExtraction.create(
+            self.app_workflow, self.command_name, 
+            self.command)
 
         if stored_params:
             _, _, _, stored_missing_fields = self._extract_missing_fields(input_for_param_extraction, self.app_workflow, self.command_name, stored_params)
         else:
             stored_missing_fields = []
-
-        new_params = input_for_param_extraction.extract_parameters(
-            command_parameters_class, 
-            self.command_name, 
-            app_workflow_folderpath)
+            
+        # If we have missing fields (in parameter extraction error state), try to apply the command directly
+        if stored_missing_fields:
+            # Apply the command directly as parameter values
+            direct_params = self._apply_missing_fields(self.command, stored_params, stored_missing_fields)
+            new_params = direct_params
+        else:
+            # Otherwise use the LLM-based extraction
+            new_params = input_for_param_extraction.extract_parameters(
+                command_parameters_class, 
+                self.command_name, 
+                app_workflow_folderpath)
 
         if stored_params:
             merged_params = self._merge_parameters(stored_params, new_params, stored_missing_fields)
@@ -363,7 +376,7 @@ class ParameterExtraction:
             if params_str := self._format_parameters_for_display(merged_params):
                 error_msg = f"Extracted parameters so far:\n{params_str}\n\n{error_msg}"
 
-            error_msg += "\nEnter 'abort' if you want to abort the command."
+            error_msg += "\nEnter 'abort' to get out of this error state and/or execute a different command."
             error_msg += "\nEnter 'you misunderstood' if the wrong command was executed."
             return self.Output(
                 parameters_are_valid=False,
@@ -415,53 +428,60 @@ class ParameterExtraction:
         """
         Merge new parameters with old parameters, prioritizing new values when appropriate.
         """
+        global PARAMETER_EXTRACTION_ERROR_MSG
+        if not PARAMETER_EXTRACTION_ERROR_MSG:
+            PARAMETER_EXTRACTION_ERROR_MSG = fastworkflow.get_env_var("PARAMETER_EXTRACTION_ERROR_MSG")
+
         merged = old_params.model_copy()
 
-        all_fields = list(old_params.model_fields.keys())
-        missing_fields = missing_fields or []
+        try:
+            all_fields = list(old_params.model_fields.keys())
+            missing_fields = missing_fields or []
 
-        for field_name in all_fields:
-            if hasattr(new_params, field_name):
-                new_value = getattr(new_params, field_name)
-                old_value = getattr(merged, field_name)
+            for field_name in all_fields:
+                if hasattr(new_params, field_name):
+                    new_value = getattr(new_params, field_name)
+                    old_value = getattr(merged, field_name)
 
-                if new_value is not None and new_value != NOT_FOUND:
-                    if isinstance(old_value, str) and INVALID in old_value and INVALID not in new_value:
-                        setattr(merged, field_name, new_value)
-
-                    elif old_value is None or old_value == NOT_FOUND:
-                        setattr(merged, field_name, new_value)
-
-                    elif isinstance(old_value, int) and old_value == INVALID_INT_VALUE:
-                        with contextlib.suppress(ValueError, TypeError):
-                            setattr(merged, field_name, int(new_value))
-
-                    elif isinstance(old_value, float) and old_value == INVALID_FLOAT_VALUE:
-                        with contextlib.suppress(ValueError, TypeError):
-                            setattr(merged, field_name, float(new_value))
-
-                    elif (field_name in missing_fields and
-                          hasattr(merged.model_fields.get(field_name), "json_schema_extra") and
-                          merged.model_fields.get(field_name).json_schema_extra and
-                          "db_lookup" in merged.model_fields.get(field_name).json_schema_extra):
-                        setattr(merged, field_name, new_value)
-
-                    elif field_name in missing_fields:
-                        field_info = merged.model_fields.get(field_name)
-                        has_pattern = hasattr(field_info, "pattern") and field_info.pattern is not None
-
-                        if not has_pattern:
-                            for meta in getattr(field_info, "metadata", []):
-                                if hasattr(meta, "pattern"):
-                                    has_pattern = True
-                                    break
-
-                        if not has_pattern and hasattr(field_info, "json_schema_extra") and field_info.json_schema_extra:
-                            has_pattern = "pattern" in field_info.json_schema_extra
-
-                        if has_pattern:
+                    if new_value is not None and new_value != NOT_FOUND:
+                        if isinstance(old_value, str) and INVALID in old_value and INVALID not in new_value:
                             setattr(merged, field_name, new_value)
 
+                        elif old_value is None or old_value == NOT_FOUND:
+                            setattr(merged, field_name, new_value)
+
+                        elif isinstance(old_value, int) and old_value == INVALID_INT_VALUE:
+                            with contextlib.suppress(ValueError, TypeError):
+                                setattr(merged, field_name, int(new_value))
+
+                        elif isinstance(old_value, float) and old_value == INVALID_FLOAT_VALUE:
+                            with contextlib.suppress(ValueError, TypeError):
+                                setattr(merged, field_name, float(new_value))
+
+                        elif (field_name in missing_fields and
+                            hasattr(merged.model_fields.get(field_name), "json_schema_extra") and
+                            merged.model_fields.get(field_name).json_schema_extra and
+                            "db_lookup" in merged.model_fields.get(field_name).json_schema_extra):
+                            setattr(merged, field_name, new_value)
+
+                        elif field_name in missing_fields:
+                            field_info = merged.model_fields.get(field_name)
+                            has_pattern = hasattr(field_info, "pattern") and field_info.pattern is not None
+
+                            if not has_pattern:
+                                for meta in getattr(field_info, "metadata", []):
+                                    if hasattr(meta, "pattern"):
+                                        has_pattern = True
+                                        break
+
+                            if not has_pattern and hasattr(field_info, "json_schema_extra") and field_info.json_schema_extra:
+                                has_pattern = "pattern" in field_info.json_schema_extra
+
+                            if has_pattern:
+                                setattr(merged, field_name, new_value)
+        except Exception as exc:
+            logger.warning(PARAMETER_EXTRACTION_ERROR_MSG.format(error=exc))
+
         return merged
 
     @staticmethod
@@ -505,34 +525,43 @@ class ParameterExtraction:
 
     @staticmethod
     def _apply_missing_fields(command: str, default_params: BaseModel, missing_fields: list):
+        global PARAMETER_EXTRACTION_ERROR_MSG
+        if not PARAMETER_EXTRACTION_ERROR_MSG:
+            PARAMETER_EXTRACTION_ERROR_MSG = fastworkflow.get_env_var("PARAMETER_EXTRACTION_ERROR_MSG")
+
         params = default_params.model_copy()
 
-        if "," in command:
-            parts = [part.strip() for part in command.split(",")]
+        try:
+            if "," in command:
+                parts = [part.strip() for part in command.split(",")]
 
-            if len(parts) == len(missing_fields):
-                if len(missing_fields) == 1:
-                    field = missing_fields[0]
-                    if hasattr(params, field):
-                        setattr(params, field, parts[0])
+                if len(parts) == len(missing_fields):
+                    if len(missing_fields) == 1:
+                        field = missing_fields[0]
+                        if hasattr(params, field):
+                            setattr(params, field, parts[0])
+                            return params
+                    elif len(missing_fields) > 1:
+                        for i, field in enumerate(missing_fields):
+                            if i < len(parts) and hasattr(params, field):
+                                setattr(params, field, parts[i])
                         return params
-                elif len(missing_fields) > 1:
-                    for i, field in enumerate(missing_fields):
-                        if i < len(parts) and hasattr(params, field):
-                            setattr(params, field, parts[i])
+                else:
+                    if parts and missing_fields:
+                        field = missing_fields[0]
+                        if hasattr(params, field):
+                            setattr(params, field, parts[0])
                     return params
-            else:
-                if parts and missing_fields:
-                    field = missing_fields[0]
-                    if hasattr(params, field):
-                        setattr(params, field, parts[0])
-                return params
 
-        elif missing_fields:
-            field = missing_fields[0]
-            if hasattr(params, field):
-                setattr(params, field, command.strip())
-                return params
+            elif missing_fields:
+                field = missing_fields[0]
+                if hasattr(params, field):
+                    setattr(params, field, command.strip())
+                    return params
+        
+        except Exception as exc:
+            # logger.warning(PARAMETER_EXTRACTION_ERROR_MSG.format(error=exc))
+            pass
 
         return params    
 
@@ -561,8 +590,6 @@ class ResponseGenerator:
         workflow: fastworkflow.Workflow, 
         command: str,
     ) -> CommandOutput:  # sourcery skip: hoist-if-from-if
-        workflow.is_complete = False
-
         app_workflow = workflow.context["app_workflow"]   # type: fastworkflow.Workflow
         cmd_ctxt_obj_name = app_workflow.current_command_context_name
         nlu_pipeline_stage = workflow.context.get(
@@ -575,8 +602,6 @@ class ResponseGenerator:
         if cnp_output.error_msg:
             workflow_context = workflow.context
             workflow_context["NLU_Pipeline_Stage"] = NLUPipelineStage.INTENT_AMBIGUITY_CLARIFICATION
-            if command not in workflow_context:
-                workflow_context["command"] = command
             workflow.context = workflow_context
             return CommandOutput(
                 command_responses=[
@@ -589,17 +614,19 @@ class ResponseGenerator:
                     )
                 ]
             )
+        else:
+            if nlu_pipeline_stage == NLUPipelineStage.INTENT_DETECTION and \
+                cnp_output.command_name != 'ErrorCorrection/you_misunderstood':
+                workflow_context = workflow.context
+                workflow_context["command"] = command
+                workflow.context = workflow_context
         
         if cnp_output.is_cme_command:
             workflow_context = workflow.context
             if cnp_output.command_name == 'ErrorCorrection/you_misunderstood':
                 workflow_context["NLU_Pipeline_Stage"] = NLUPipelineStage.INTENT_MISUNDERSTANDING_CLARIFICATION
-                if command not in workflow_context:
-                    workflow_context["command"] = command
             else:
-                workflow.is_complete = True
-                workflow_context["NLU_Pipeline_Stage"] = NLUPipelineStage.INTENT_DETECTION
-                workflow_context.pop("command", None)
+                workflow.end_command_processing()
             workflow.context = workflow_context
 
             startup_action = Action(
@@ -636,8 +663,6 @@ class ResponseGenerator:
                         workflow_context = workflow.context
                         workflow_context["NLU_Pipeline_Stage"] = \
                             NLUPipelineStage.INTENT_MISUNDERSTANDING_CLARIFICATION
-                        if command not in workflow_context:
-                            workflow_context["command"] = command
                         workflow.context = workflow_context
 
                         startup_action = Action(
@@ -661,7 +686,6 @@ class ResponseGenerator:
             workflow_context = workflow.context
             workflow_context["NLU_Pipeline_Stage"] = NLUPipelineStage.PARAMETER_EXTRACTION
             workflow_context["command_name"] = cnp_output.command_name
-            workflow_context["command"] = command
             workflow.context = workflow_context
 
         command_name = workflow.context["command_name"]
@@ -669,6 +693,7 @@ class ResponseGenerator:
         pe_output = extractor.extract()
         if not pe_output.parameters_are_valid:
             return CommandOutput(
+                command_name = command_name,
                 command_responses=[
                     CommandResponse(
                         response=(
@@ -680,16 +705,14 @@ class ResponseGenerator:
                 ]
             )
 
-        workflow.is_complete = True
-        workflow.context["NLU_Pipeline_Stage"] = \
-            NLUPipelineStage.INTENT_DETECTION
+        workflow.end_command_processing()
 
         return CommandOutput(
             command_responses=[
                 CommandResponse(
                     response="",
                     artifacts={
-                        "command": workflow.context["command"],
+                        "command": command,
                         "command_name": command_name,
                         "cmd_parameters": pe_output.cmd_parameters,
                     },
