@@ -6,12 +6,17 @@ from collections import deque
 import json
 import contextlib
 import uuid
+from pathlib import Path
+import os
+
+import dspy
 
 import fastworkflow
 from fastworkflow.utils.logging import logger
-from pathlib import Path
+from fastworkflow.utils import dspy_utils
 from fastworkflow.model_pipeline_training import CommandRouter
 from fastworkflow.utils.startup_progress import StartupProgress
+from fastworkflow.command_metadata_api import CommandMetadataAPI
 
 
 class SessionStatus(Enum):
@@ -234,6 +239,12 @@ class ChatSession:
         # Push this workflow as active
         ChatSession.push_active_workflow(workflow)
         
+        # Initialize workflow tool agent if in agent mode
+        # This must happen after pushing the workflow to the stack
+        # so that get_active_workflow() returns the correct workflow
+        if self._run_as_agent:
+            self._initialize_workflow_tool_agent()
+        
         command_output = None
         if self._keep_alive:
             # Root workflow gets a worker thread
@@ -254,7 +265,7 @@ class ChatSession:
         if not self._workflow_tool_agent:
             # Initialize the workflow tool agent
             from fastworkflow.mcp_server import FastWorkflowMCPServer
-            from fastworkflow.agent_integration import initialize_workflow_tool_agent
+            from fastworkflow.workflow_agent import initialize_workflow_tool_agent
             
             mcp_server = FastWorkflowMCPServer(self)
             self._workflow_tool_agent = initialize_workflow_tool_agent(mcp_server)
@@ -301,7 +312,11 @@ class ChatSession:
         try:
             # Handle startup command/action
             if self._startup_command:
-                last_output = self._process_message(self._startup_command)
+                if self._run_as_agent:
+                    # In agent mode, use workflow tool agent for processing
+                    last_output = self._process_agent_message(self._startup_command)
+                else:
+                    last_output = self._process_message(self._startup_command)
             elif self._startup_action:
                 last_output = self._process_action(self._startup_action)
 
@@ -397,29 +412,46 @@ class ChatSession:
         """Process a message in agent mode using workflow tool agent"""
         # The agent processes the user's message and may make multiple tool calls
         # to the workflow internally (directly via CommandExecutor)
-        agent_result = self._workflow_tool_agent(tool_request=message)
-        
+
+        # Ensure any prior action log is removed before a fresh agent run
+        if os.path.exists("action.json"):
+            os.remove("action.json")
+
+        refined_message = f'messsage\n{self._think_and_plan(message)}'
+
+        lm = dspy_utils.get_lm("LLM_AGENT", "LITELLM_API_KEY_AGENT")
+        with dspy.context(lm=lm):
+            agent_result = self._workflow_tool_agent(user_query=refined_message)
+            # dspy.inspect_history(n=1)
+
         # Extract the final result from the agent
         result_text = (
-            agent_result.tool_result
-            if hasattr(agent_result, 'tool_result')
+            agent_result.final_answer
+            if hasattr(agent_result, 'final_answer')
             else str(agent_result)
         )
-        
+
         # Create CommandOutput with the agent's response
+        command_response = fastworkflow.CommandResponse(response=result_text)
+        # Attach actions captured during agent execution as artifacts if available
+        if os.path.exists("action.json"):
+            with open("action.json", "r", encoding="utf-8") as f:
+                actions = [json.loads(line) for line in f if line.strip()]
+            command_response.artifacts["extracted_actions"] = actions
+
         command_output = fastworkflow.CommandOutput(
-            command_responses=[fastworkflow.CommandResponse(response=result_text)]
+            command_responses=[command_response]
         )
-        
+
         # Put output in queue (following same pattern as _process_message)
         if (not command_output.success or self._keep_alive) and \
-            self.command_output_queue:
+                self.command_output_queue:
             self.command_output_queue.put(command_output)
-        
+
         # Persist workflow state changes
         if workflow := ChatSession.get_active_workflow():
             workflow.flush()
-        
+
         return command_output
     
     def profile_invoke_command(self, message: str):
@@ -433,7 +465,6 @@ class ChatSession:
         Returns:
             The result of the invoke_command call
         """
-        import os
         from datetime import datetime
         
         # Generate a unique filename with timestamp
@@ -443,7 +474,6 @@ class ChatSession:
         import cProfile
         import pstats
         import io
-        import os
         import time
         
         # Create a Profile object
@@ -542,3 +572,33 @@ class ChatSession:
             workflow.flush()
 
         return command_output
+
+    def _think_and_plan(self, user_query: str) -> str:
+        """
+        Returns a refined plan by breaking down a user_query into simpler tasks based only on available commands and returns a todo list.
+        """
+        class TaskPlannerSignature(dspy.Signature):
+            """
+            Break down a user_query into simpler tasks based only on available commands and return a todo list.
+            If user_query is simple, return a single todo that is the user_query as-is
+            """
+            user_query: str = dspy.InputField()
+            available_commands: list[str] = dspy.InputField()
+            todo_list: list[str] = dspy.OutputField(desc="task descriptions as short sentences")
+
+        current_workflow = ChatSession.get_active_workflow()
+        available_commands = CommandMetadataAPI.get_command_display_text(
+            subject_workflow_path=current_workflow.folderpath,
+            cme_workflow_path=fastworkflow.get_internal_workflow_path("command_metadata_extraction"),
+            active_context_name=current_workflow.current_command_context_name,
+        )
+
+        planner_lm = dspy_utils.get_lm("LLM_PLANNER", "LITELLM_API_KEY_PLANNER")
+        with dspy.context(lm=planner_lm):
+            task_planner_func = dspy.ChainOfThought(TaskPlannerSignature)
+            prediction = task_planner_func(user_query=user_query, available_commands=available_commands)
+
+            if not prediction.todo_list or (len(prediction.todo_list) == 1 and prediction.todo_list[0] == user_query):
+                return user_query
+
+            return f"{user_query}\nNext steps:\n{'\n'.join([f'{i + 1}. {task}' for i, task in enumerate(prediction.todo_list)])}"
