@@ -253,7 +253,8 @@ def find_default_env_files(workflow_path):
     Returns:
         tuple: (env_file_path, passwords_file_path)
     """
-    workflow_path = Path(workflow_path)        
+    # Resolve the workflow path to absolute path to handle relative paths correctly
+    workflow_path = Path(workflow_path).resolve()        
     return workflow_path / "fastworkflow.env", workflow_path / "fastworkflow.passwords.env"
 
 def add_build_parser(subparsers):
@@ -276,6 +277,24 @@ def add_build_parser(subparsers):
 
     parser_build.set_defaults(func=_build_main_wrapper)
 
+def add_refine_parser(subparsers):
+    """Add subparser for the 'refine' command."""
+    parser_refine = subparsers.add_parser(
+        "refine",
+        help="Refine generated commands: enhance metadata and build dependency graph.",
+        formatter_class=argparse.ArgumentDefaultsHelpFormatter,
+    )
+    parser_refine.add_argument('--workflow-folderpath', '-w', required=True, help='Path to the workflow folder to refine')
+    parser_refine.add_argument('--semantic-threshold', type=float, default=0.85, help='Semantic match threshold for dependency graph')
+    parser_refine.add_argument('--exact-only', action='store_true', help='Use exact name/type matching only for dependency graph')
+
+    # Lazy-import refine_main only if the user actually invokes the command
+    def _refine_main_wrapper(args):
+        from .refine.__main__ import refine_main as _refine_main
+        return _refine_main(args)
+
+    parser_refine.set_defaults(func=_refine_main_wrapper)
+
 def add_train_parser(subparsers):
     """Add subparser for the 'train' command."""
     parser_train = subparsers.add_parser("train", help="Train the intent detection pipeline for a workflow.")
@@ -319,6 +338,12 @@ def add_run_parser(subparsers):
     parser_run.add_argument("--startup_action", help="Optional startup action", default="")
     parser_run.add_argument("--keep_alive", help="Optional keep_alive", default=True)
     parser_run.add_argument("--project_folderpath", help="Optional path to project folder containing application code", default=None)
+    parser_run.add_argument(
+        "--run_as_agent",
+        help="Run in agent mode (uses DSPy for tool selection)",
+        action="store_true",
+        default=False,
+    )
     parser_run.set_defaults(func=lambda args: run_with_defaults(args))
 
 def train_with_defaults(args):  # sourcery skip: extract-duplicate-method
@@ -466,6 +491,10 @@ def run_example(args):
         str(passwords_file)
     ]
 
+    # Forward agent mode flag if requested
+    if getattr(args, "run_as_agent", False):
+        cmd.append("--run_as_agent")
+
     try:
         rprint(f"[bold green]Starting interactive session...[/bold green]")
         # Replace the current process with the run command
@@ -507,10 +536,17 @@ def main():
     # 'examples run' command
     parser_run_example = examples_subparsers.add_parser("run", help="Run a specific example")
     parser_run_example.add_argument("name", help="The name of the example to run")
+    parser_run_example.add_argument(
+        "--run_as_agent",
+        help="Run the example in agent mode (uses DSPy for tool selection)",
+        action="store_true",
+        default=False,
+    )
     parser_run_example.set_defaults(func=run_example)
     
     # Add top-level commands
     add_build_parser(subparsers)
+    add_refine_parser(subparsers)
     add_train_parser(subparsers)
     add_run_parser(subparsers)
 
