@@ -14,24 +14,37 @@ class Signature:
     class Input(BaseModel):
         order_id: str = Field(
             default="NOT_FOUND",
-            description="The order ID to exchange (must start with #)",
-            pattern=r"^(#[\w\d]+|NOT_FOUND)$",
-            examples=["#W0000000"],
+            description="The order ID to exchange",
+            pattern=r"^(#?[\w\d]+|NOT_FOUND)$",
+            examples=["#W00000000"],
+            json_schema_extra={
+                "available_from": ["get_user_details"]
+            }
         )
         item_ids: List[str] = Field(
             default_factory=list,
             description="The item IDs to be exchanged",
             examples=["1008292230"],
+            json_schema_extra={
+                "available_from": ["get_order_details"]
+            }
         )
         new_item_ids: List[str] = Field(
             default_factory=list,
             description="The new item IDs to exchange for",
             examples=["1008292230"],
+            json_schema_extra={
+                "available_from": ["get_product_details"]
+            }
         )
         payment_method_id: str = Field(
             default="NOT_FOUND",
-            description="Payment method ID for price difference. You can get this from order details->payment_history",
-            examples=["gift_card_0000000", "credit_card_0000000"],
+            description="Payment method ID for price difference.",
+            pattern=r"^((gift_card|credit_card|paypal)_\d+|NOT_FOUND)$",
+            examples=["gift_card_0000000", "credit_card_0000000", "paypal_0000000"],
+            json_schema_extra={
+                "available_from": ["get_order_details", "get_user_details"]
+            }
         )
 
         model_config = ConfigDict(arbitrary_types_allowed=True, validate_assignment=True)
@@ -55,6 +68,15 @@ class Signature:
         from fastworkflow.train.generate_synthetic import generate_diverse_utterances
         return generate_diverse_utterances(utterances_obj.plain_utterances, command_name)
 
+    @staticmethod
+    def validate_extracted_parameters(
+        workflow: fastworkflow.Workflow, 
+        command: str, cmd_parameters: "Signature.Input"
+    ) -> tuple[bool, str]:
+        if not cmd_parameters.order_id.startswith('#'):
+            cmd_parameters.order_id = f'#{cmd_parameters.order_id}'
+        return (True, '')
+
 
 class ResponseGenerator:
     def __call__(self, workflow: Workflow, command: str, command_parameters: Signature.Input) -> CommandOutput:
