@@ -14,25 +14,37 @@ class Signature:
     class Input(BaseModel):
         order_id: str = Field(
             default="NOT_FOUND",
-            description="The order ID to modify (must start with #)",
-            pattern=r"^(#W\d+|NOT_FOUND)$",
+            description="The order ID to modify",
+            pattern=r"^(#?[\w\d]+|NOT_FOUND)$",
             examples=["#W0000000"],
+            json_schema_extra={
+                "available_from": ["get_user_details"]
+            }
         )
         item_ids: List[str] = Field(
             default_factory=list,
             description="List of item IDs to be modified",
             examples=["1008292230", "2468135790"],
+            json_schema_extra={
+                "available_from": ["get_order_details"]
+            }
         )
         new_item_ids: List[str] = Field(
             default_factory=list,
             description="List of new item IDs to replace with",
             examples=["1008292231", "2468135791"],
+            json_schema_extra={
+                "available_from": ["get_product_details"]
+            }
         )
         payment_method_id: str = Field(
             default="NOT_FOUND",
             description="Payment method ID for price differences",
-            pattern=r"^((gift_card|credit_card)_\d+|NOT_FOUND)$",
-            examples=["gift_card_0000000", "credit_card_0000000"],
+            pattern=r"^((gift_card|credit_card|paypal)_\d+|NOT_FOUND)$",
+            examples=["gift_card_0000000", "credit_card_0000000", "paypal_0000000"],
+            json_schema_extra={
+                "available_from": ["get_order_details", "get_user_details"]
+            }
         )
 
         model_config = ConfigDict(arbitrary_types_allowed=True, validate_assignment=True)
@@ -56,6 +68,15 @@ class Signature:
         from fastworkflow.train.generate_synthetic import generate_diverse_utterances
         return generate_diverse_utterances(utterances_obj.plain_utterances, command_name)
 
+    @staticmethod
+    def validate_extracted_parameters(
+        workflow: fastworkflow.Workflow, 
+        command: str, cmd_parameters: "Signature.Input"
+    ) -> tuple[bool, str]:
+        if not cmd_parameters.order_id.startswith('#'):
+            cmd_parameters.order_id = f'#{cmd_parameters.order_id}'
+        return (True, '')
+
 
 class ResponseGenerator:
     def __call__(self, workflow: Workflow, command: str, command_parameters: Signature.Input) -> CommandOutput:
